//#define XERR "multibuf"
//#define SRC XERR "/" __FILE__ ": "

#include "multibuf.ih"

MultiBuf::Mode MultiBuf::mode(ostream &out) const
{
    Stream const *str = find(out);

    return str != 0 ? str->d_mode : OFF;
}
