#define XERR "flock"
#include "flock.ih"

    // by flock.f (tryLock)

void Flock::notifyLock(int lockType)
{
    d_ok = false;
    d_sem.set(0);           
                            // may be interrupted by d_sem.wait_for(...)
    d_ok = flock(d_fd, lockType) != -1;

    d_sem.notify();
}
