#define XERR "memoryaccess"
#include "memoryaccess.ih"

    // by memorybridge/memorybridge4.cc

// static
MemoryAccess *MemoryAccess::loadID(int id)
{
    void *ptr = MemoryAccess::connect(id);

    if (ptr == 0)
        throw Exception{} << "No MemoryAccess " << id;

    // MemoryAccess *ma = static_cast<MemoryAccess *>(ptr);
    // ma->info(cerr);
    
    return static_cast<MemoryAccess *>(ptr);
}

