#define XERR "memoryaccess"
#include "memoryaccess.ih"

    // by memorybridge/write.f

size_t MemoryAccess::write(char const *src, size_t len, size_t offset)
{
                                        // write 'len' bytes (or until the
                                        // physical maximum, upddates d_offset
    len = io(src, len, &memWrite, offset);

    if (len > 0)
        d_writtenUntil = max(d_writtenUntil, offset + len);

    return len;
}
