#define XERR "flock"
#include "flock.ih"

    // by unlock.cc, flock.f (lockThread)

// static
void Flock::requireFD() const
{
    if (d_fd == -1)
        throw Exception{} << "no file descriptor of the lock file";
}
