#define XERR "memoryaccess"
#include "memoryaccess.ih"

    // by read.cc

// static
void MemoryAccess::memRead(char const *dest, char const *src, size_t count)
{
    memcpy(const_cast<char *>(dest), src, count);
}
