#include "argconfig.ih"

// static
ArgConfig &ArgConfig::init(int accept, char const *optstring,
            LongOption const *begin, LongOption const *const end,
            int argc, char **argv,
            string const &fname,
            Comment cType, SearchCasing sType, Indices iType)
{
    static ArgConfig argConfig{ accept, optstring,
                                begin, end,
                                argc, argv,
                                fname,
                                cType, sType, iType };

    s_argConfig = &argConfig;

    return argConfig;
}
