#include "multibuf.ih"

// overrides
int MultiBuf::sync()
{
    for (auto &str: d_os)
    {
        switch (str.d_mode)
        {
            case ONCE:
                str.d_mode = RESET;
            [[fallthrough]];

            case ON:
                str.d_ostrPtr->flush();
            break;

            default:
            break;
        }
    }
    return 0;                           // OK
}

