//#define XERR "multibuf"
//#define SRC XERR "/" __FILE__ ": "

#include "multibuf.ih"

bool MultiBuf::setOnce(size_t idx)
{
    if (idx >= size())
        return false;

    d_os[idx].d_mode = ONCE;
    return true;
}
