//#define XERR "multibuf"
//#define SRC XERR "/" __FILE__ ": "

#include "multibuf.ih"

bool MultiBuf::reset(ostream &out, Mode mode)
{
    Stream *strPtr = find(out);
    if (strPtr == 0)
        return false;

    strPtr->d_mode = mode;
    return true;
}
