//#define XERR "memorybuf"
#include "memorybuf.ih"

    // by memorystream/open.cc

MemoryBuf &MemoryBuf::operator=(MemoryBuf &&tmp)
{
    streambuf::swap(tmp);           // swap the streambuf
    fswap(&d_last, *this, tmp);     // swap the memorybuf's own data members

    return *this;
}
