#include "multibuf.ih"

std::streamsize MultiBuf::write(char const *buffer, streamsize nChars)
{
    for (Stream &str: d_os)
    {
        switch (str.d_mode)
        {
            case ONCE:
            case ON:
                str.d_ostrPtr->write(buffer, nChars);
            break;

            default:
            break;
        }
    };
    return nChars;
}
