#define XERR "memorybuf"
#include "memorybuf.ih"

// overrides
ios::pos_type MemoryBuf::seekpos(ios::pos_type offset, ios::openmode mode)
{
//xerr("offset = " << offset << ", way = " << ios::beg);

    return seekoff(offset, ios::beg, mode);
}
