#define XERR "flock"
#include "flock.ih"

    // by 

Flock::Flock(string const &filename, mode_t mode)
:
    d_fd(-1),
    d_sem(0)
{
    setFilename(filename, mode);                // the name of the lockfile
}
