#define XERR
#include "memorybridge.ih"

    // by sharedbuf/showmanyc.cc
std::streamsize MemoryBridge::showmanyc() const
{
    size_t writtenUntil = requireAccess().writtenUntil();

    return writtenUntil <= d_offset ? 0 : writtenUntil - d_offset;
}
