////#define XERR "memorybuf"
//#include "memorybuf.ih"
//
//    // by X
//
//MemoryBuf &MemoryBuf::operator=(MemoryBuf &&tmp)
//{
//    xerr("move = starts");
//    swap( static_cast<streambuf &>(*this), static_cast<streambuf>(tmp) );
//    xerr("move = ends");
//    return *this;
//}
//
