#include "readlinehistory.ih"

ReadLineHistory &ReadLineHistory::instance(bool useTimestamps)
{
    if (s_readLineHistory == 0)
    {
        static ReadLineHistory history;
        s_readLineHistory = &history;
    }

    s_readLineHistory->setTimestampsIO(useTimestamps);

    return *s_readLineHistory;
}
