#include "multibuf.ih"

// overrides
int MultiBuf::overflow(int ch)
{
    if (ch == EOF)
    {
        sync();
        return 0;
    }
    write(reinterpret_cast<char const *>(&ch), 1);
    return ch;
}
